Struct ShapeRegistry
pub struct ShapeRegistry {
shapes: Vec<VoxelShape>,
allows_registering: bool,
}Expand description
Registry for VoxelShapes.
Shapes are registered once and referenced by ShapeId. This allows
deduplication of shapes and compact storage of shape references.
Vanilla shapes are registered at startup. Plugins can register additional shapes for custom blocks.
Fields
shapes: Vec<VoxelShape>allows_registering: boolImplementations
impl ShapeRegistry
impl ShapeRegistry
pub fn new() -> ShapeRegistry
pub fn new() -> ShapeRegistry
Creates a new shape registry with the standard empty and full block shapes.
pub fn register(&mut self, shape: VoxelShape) -> ShapeId
pub fn register(&mut self, shape: VoxelShape) -> ShapeId
pub fn get(&self, id: ShapeId) -> VoxelShape
pub fn get(&self, id: ShapeId) -> VoxelShape
Gets the shape for a given ID.
Returns an empty shape if the ID is invalid.
pub const fn freeze(&mut self)
pub const fn freeze(&mut self)
Freezes the registry, preventing further registrations.